using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Net;
using System.Net.NetworkInformation;
using System.Media;
using System.IO;
using Microsoft.Win32;
using System.Reflection;



namespace BinIchSchonDrin
{
    public partial class FormOptionen : Form
    {
        string HostNameOrAddress;
        int Timeout;
        bool PingFlanke;
        string SoundDatei;
        SoundPlayer simpleSound;
        Properties.Settings mySettings = new Properties.Settings();

        public FormOptionen()
        {
            InitializeComponent();

            LoadConfigSettings();   // Einstellungen laden
        }

        // Einstellungen speichern/laden -> user.config
        private void LoadConfigSettings()
        {
            HostNameOrAddress = mySettings.HostNameOrAddress;
            Timeout = mySettings.Timeout;
            timer1.Interval = mySettings.timer1Interval;
            SoundDatei = mySettings.SoundDatei;
            checkBoxberwachung.Checked = mySettings.checkBoxberwachung;
            checkBoxAutostart.Checked = mySettings.checkBoxAutostart;
        }
        private void SaveConfigSettings()
        {
            mySettings.HostNameOrAddress = HostNameOrAddress;
            mySettings.Timeout = Timeout;
            mySettings.timer1Interval = timer1.Interval;
            mySettings.SoundDatei = SoundDatei;
            mySettings.checkBoxberwachung = checkBoxberwachung.Checked;
            mySettings.checkBoxAutostart = checkBoxAutostart.Checked;

            mySettings.Save();
        }

        // Option Fenster
        private void FormOptionen_Load(object sender, EventArgs e)
        {
            this.Hide();        // Fenster verstecken

            // Einstellungen in das Fenster schreiben
            textBoxAdresse.Text = HostNameOrAddress;    // Adresse
            textBoxTimeout.Text = Timeout.ToString();   // Timeout
            int tmp = timer1.Interval / 1000;           // Ping Interval
            textBoxIntervall.Text = tmp.ToString();
            openFileDialogSoundffnen.FileName = SoundDatei;    // Sound Datei
            LabelSoundPfad.Text = System.IO.Path.GetFileName(SoundDatei);
        }
        private void buttonSoundffnen_Click(object sender, EventArgs e)
        {
            openFileDialogSoundffnen.ShowDialog();
        }
        private void openFileDialogSoundffnen_FileOk(object sender, CancelEventArgs e)
        {
            LabelSoundPfad.Text = Path.GetFileName(openFileDialogSoundffnen.FileName);
        }
        private void buttonPlay_Click(object sender, EventArgs e)
        {
            SoundPlay(openFileDialogSoundffnen.FileName);
        }
        private void buttonOK_Click(object sender, EventArgs e)
        {
            // Lokale Variablen
            RegistryKey regKey = Registry.CurrentUser.OpenSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Run", true);
            FileInfo fi = new FileInfo(Assembly.GetEntryAssembly().Location);

            // Ping ein ausschalten
            if (checkBoxberwachung.Checked)
            {
                timer1.Enabled = true;
                LabelPingStatus.Text = "noch kein Ping gesendet";
                notifyIcon.Icon = Properties.Resources.timeout;
            }
            else
            {
                timer1.Enabled = false;
                LabelPingStatus.Text = "Ping ist ausgeschaltet";
                notifyIcon.Icon = Properties.Resources.ausgeschaltet;
            }

            // Autostart ein ausschalten
            if (checkBoxAutostart.Checked)
            {
                regKey.SetValue("BinIchSchonDrin", fi.FullName.ToString());
                regKey.Close();
            }
            else
            {
                regKey.DeleteValue("BinIchSchonDrin");
                regKey.Close();
            }

            try 
            {
                // Gltigkeitsabfrage der Einstellungen
                if (Int32.Parse(textBoxIntervall.Text) * 1000 <= Int32.Parse(textBoxTimeout.Text))
                {
                    throw new MyException("Interval muss groer als Timeout sein!");
                }

                // Einstellungen in Variablen schreiben
                HostNameOrAddress = textBoxAdresse.Text;                    // Adresse
                Timeout = Int32.Parse(textBoxTimeout.Text);                 // Timeout            
                timer1.Interval = Int32.Parse(textBoxIntervall.Text) * 1000; // Ping Interval
                SoundDatei = openFileDialogSoundffnen.FileName;            // Sound Datei

                this.Hide();    // Fenster verstecken
            }
            catch (Exception x)
            {
                MessageBox.Show("Fehlerhafte eingabe\r\n" + x.Message + "\r\n" + x.InnerException, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }
        private void buttonAbbrechen_Click(object sender, EventArgs e)
        {
            FormOptionen_Load(sender, e);   // ursprngliche Einstellungen wieder in das Fenster schreiben
            this.Hide();    // Fenster verstecken
        }
        private void FormOption_Resize(object sender, EventArgs e)
        {
            // Versteckt das Fenster beim minimieren
            if (this.WindowState == FormWindowState.Minimized)
            {
                this.Hide();    // Fenster verstecken
            }

        }
        private void FormOptionrn_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (e.CloseReason == CloseReason.UserClosing)
            {
                e.Cancel = true;    // Programm NICHT beenden 
                this.Hide();        // Fenster verstecken
            }
            else    // Jeder andere schlieen grund
            {
                SaveConfigSettings();   // Einstellungen speichern
            }
        }

        // Tray Icon
        private void notifyIcon_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            // Options Fenster sichtbar machen
            this.ShowInTaskbar = true;
            this.Show();
            this.WindowState = FormWindowState.Normal;
        }

        // Ping
        private void timer1_Tick(object sender, EventArgs e)
        {
            Ping pingSender = new Ping();

            try
            {
                PingReply reply = pingSender.Send(HostNameOrAddress, Timeout);

                if (reply.Status == IPStatus.Success)   // Ping erfolgreich
                {
                    notifyIcon.Icon = Properties.Resources.verbunden;
                    LabelPingStatus.Text = "letzte Ping Zeit " + reply.RoundtripTime.ToString() + "ms";
                    notifyIcon.Text = "Prft Online Status\n" + LabelPingStatus.Text;
                }
                else if (reply.Status == IPStatus.TimedOut)    // Ping Nicht erfolgreich
                {
                    PingFlanke = false;
                    LabelPingStatus.Text = "letzter Ping NICHT erfolgreich";
                    notifyIcon.Icon = Properties.Resources.timeout;
                    notifyIcon.Text = "Prft Online Status\n" + "Timeout";
                }

                if (reply.Status == IPStatus.Success && !PingFlanke)   // Ping erfolgreich und _posFlanke_
                {
                    PingFlanke = true;
                    SoundPlay(SoundDatei);
                }

            }
            catch (PingException x)
            {
                // Fehler verwerfen!!!
                //x.InnerException      // Whrend einer Pinganforderung ist eine Ausnahme aufgetreten.
                //x.Message             // Der angegebene Host ist unbekann             
            }
        }        

        // Programm Beenden
        private void buttonBeenden_Click(object sender, EventArgs e)
        {
            // Geenderte Einstellungen die noch nicht mit OK bettigt wurden, werden verworfen !!!!!!!!!
            Application.Exit();
        }

        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process P = new System.Diagnostics.Process();
            P.StartInfo.FileName = "http://www.black-strom.de.vu/";
            P.Start();   
        }

        private void SoundPlay(string soundDatei)
        {
            try
            {
                simpleSound = new SoundPlayer(soundDatei);
                simpleSound.Play();
            }
            catch (FileNotFoundException e)
            {
                MessageBox.Show(e.Message + Environment.NewLine + e.FileName , "BinIchSchonDrin Fehler", MessageBoxButtons.OK, MessageBoxIcon.Error);             
            }
        }

    }

    public class MyException : System.Exception
    {
        string myMessage;
        public MyException(string FehlerMeldung)
        {
            myMessage = FehlerMeldung;
        }
        public override string Message
        {
            get { return myMessage; }
        }
    }

}